@@ -290,6 +290,24 @@ from pudb.ui_tools import make_hotkey_markup, labelled_value, \
 from pudb.var_view import FrameVarInfoKeeper
 
 
+from urwid.raw_display import Screen
+
+class ThreadsafeScreen(Screen):
+    "A Screen subclass that doesn't crash when running from a non-main thread."
+
+    def signal_init(self):
+        "Initialize signal handler, ignoring errors silently."
+        try:
+            super(ThreadsafeScreen, self).signal_init()
+        except ValueError:
+            pass
+
+    def signal_restore(self):
+        "Restore default signal handler, ignoring errors silently."
+        try:
+            super(ThreadsafeScreen, self).signal_restore()
+        except ValueError:
+            pass
 
 
 class DebuggerUI(FrameVarInfoKeeper):
@@ -1097,9 +1115,7 @@ class DebuggerUI(FrameVarInfoKeeper):
 
         # {{{ setup
 
-        import urwid.raw_display as display
-
-        self.screen = display.Screen()
+        self.screen = ThreadsafeScreen()
         self.setup_palette(self.screen)
 
         self.show_count = 0
@@ -1256,9 +1272,11 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "look familiar.\n\n"
                     "If you're new here, welcome! The help screen (invoked by hitting "
                     "'?' after this message) should get you on your way.\n"
-                    "\nNew features in version 2011.3.1:\n\n"
-                    "- Work-aroudn for bug in urwid >= 1.0.\n"
-                    "\nNew features in version 2011.3:\n\n"
+                    "\nChanges in version 2012.1:\n\n"
+                    "- Work around an API change in IPython 0.12.\n"
+                    "\nChanges in version 2011.3.1:\n\n"
+                    "- Work-around for bug in urwid >= 1.0.\n"
+                    "\nChanges in version 2011.3:\n\n"
                     "- Finer-grained string highlighting (submitted by Aaron Meurer)\n"
                     "- Prefs tweaks, instant-apply, top-down stack (submitted by Aaron Meurer)\n"
                     "- Size changes in sidebar boxes (submitted by Aaron Meurer)\n"
@@ -1266,13 +1284,13 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "- Support for IPython 0.11 (submitted by Chris Farrow)\n"
                     "- Suport for custom stringifiers (submitted by Aaron Meurer)\n"
                     "- Line wrapping in variables view (submitted by Aaron Meurer)\n"
-                    "\nNew features in version 2011.2:\n\n"
+                    "\nChanges in version 2011.2:\n\n"
                     "- Fix for post-mortem debugging (submitted by 'Sundance')\n"
-                    "\nNew features in version 2011.1:\n\n"
+                    "\nChanges in version 2011.1:\n\n"
                     "- Breakpoints saved between sessions\n"
                     "- A new 'dark vim' theme\n"
                     "(both contributed by Naveen Michaud-Agrawal)\n"
-                    "\nNew features in version 0.93:\n\n"
+                    "\nChanges in version 0.93:\n\n"
                     "- Stored preferences (no more pesky IPython prompt!)\n"
                     "- Themes\n"
                     "- Line numbers (optional)\n"
