@@ -112,11 +112,22 @@ def run_ipython_shell_v11(locals, globals, first_time):
 
 def _update_ns(shell, locals, globals):
     '''Update the IPython 0.11 namespace at every visit'''
+
     shell.user_ns = locals.copy()
-    shell.user_global_ns = globals
+
+    try:
+        shell.user_global_ns = globals
+    except AttributeError:
+        class DummyMod(object):
+            "A dummy module used for IPython's interactive namespace."
+            pass
+
+        user_module = DummyMod()
+        user_module.__dict__ = globals
+        shell.user_module = user_module
+
     shell.init_user_ns()
     shell.init_completer()
-    return
 
 # Set the proper ipython shell
 if HAVE_IPYTHON and hasattr(IPython, 'Shell'):
